@@ -29,7 +29,7 @@ case "$1_$2" in
     echo "glibc,libXScrnSaver >= 1.2.3,ca-certificates"
     ;;
 # opensuse distros
-"suse15_4_linux_client" | "suse15_5_linux_client" | "suse15_6_linux_client")
+"suse15_4_linux_client" | "suse15_5_linux_client" | "suse15_6_linux_client" | "suse16_0_linux_client")
     echo "glibc,libXss1 >= 1.2.2,ca-certificates"
     ;;
 
