@@ -1,7 +1,7 @@
 /*
  * This file is part of BOINC.
- * http://boinc.berkeley.edu
- * Copyright (C) 2021 University of California
+ * https://boinc.berkeley.edu
+ * Copyright (C) 2022 University of California
  *
  * BOINC is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License
@@ -33,9 +33,13 @@ import android.view.View
 import android.view.ViewGroup
 import android.view.Window
 import androidx.core.net.toUri
+import androidx.core.view.MenuHost
+import androidx.core.view.MenuProvider
 import androidx.fragment.app.Fragment
+import androidx.lifecycle.Lifecycle
 import androidx.lifecycle.lifecycleScope
-import edu.berkeley.boinc.adapter.ProjectControlsListAdapter
+import androidx.recyclerview.widget.LinearLayoutManager
+import edu.berkeley.boinc.adapter.ProjectControlsRecyclerViewAdapter
 import edu.berkeley.boinc.adapter.ProjectsListAdapter
 import edu.berkeley.boinc.attach.ManualUrlInputFragment
 import edu.berkeley.boinc.databinding.DialogConfirmBinding
@@ -71,20 +75,42 @@ class ProjectsFragment : Fragment() {
         }
     }
 
-    override fun onCreate(savedInstanceState: Bundle?) {
-        setHasOptionsMenu(true) // enables fragment specific menu
-        super.onCreate(savedInstanceState)
-    }
-
     override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
         Logging.logVerbose(Logging.Category.GUI_VIEW, "ProjectsFragment onCreateView")
 
         // Inflate the layout for this fragment
         val binding = ProjectsLayoutBinding.inflate(inflater, container, false)
-        listAdapter = ProjectsListAdapter(activity, binding.projectsList, R.id.projects_list, data)
+        listAdapter = ProjectsListAdapter(requireActivity(), binding.projectsList, R.id.projects_list, data)
         return binding.root
     }
 
+    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
+        super.onViewCreated(view, savedInstanceState)
+
+        val menuHost: MenuHost = requireActivity() // enables fragment specific menu
+
+        // add the project menu to the fragment
+        menuHost.addMenuProvider(object: MenuProvider {
+            override fun onCreateMenu(menu: Menu, menuInflater: MenuInflater) {
+                menuInflater.inflate(R.menu.projects_menu, menu)
+            }
+
+            override fun onMenuItemSelected(menuItem: MenuItem): Boolean {
+                Logging.logDebug(Logging.Category.USER_ACTION, "AttachProjectListActivity onOptionsItemSelected()")
+
+                return when (menuItem.itemId) {
+                    R.id.projects_add_url -> {
+                        val dialog2 = ManualUrlInputFragment()
+                        dialog2.show(parentFragmentManager, getString(R.string.attachproject_list_manual_button))
+                        true
+                    }
+                    else -> true
+                }
+            }
+        }, viewLifecycleOwner, Lifecycle.State.RESUMED)
+
+    }
+
     override fun onPause() {
         Logging.logDebug(Logging.Category.GUI_VIEW, "ProjectsFragment onPause()")
 
@@ -100,25 +126,6 @@ class ProjectsFragment : Fragment() {
         requireActivity().registerReceiver(mClientStatusChangeRec, ifcsc)
     }
 
-    override fun onCreateOptionsMenu(menu: Menu, inflater: MenuInflater) {
-        // appends the project specific menu to the main menu.
-        inflater.inflate(R.menu.projects_menu, menu)
-        super.onCreateOptionsMenu(menu, inflater)
-    }
-
-    override fun onOptionsItemSelected(item: MenuItem): Boolean {
-        Logging.logDebug(Logging.Category.USER_ACTION, "AttachProjectListActivity onOptionsItemSelected()")
-
-        return when (item.itemId) {
-            R.id.projects_add_url -> {
-                val dialog2 = ManualUrlInputFragment()
-                dialog2.show(parentFragmentManager, getString(R.string.attachproject_list_manual_button))
-                true
-            }
-            else -> super.onOptionsItemSelected(item)
-        }
-    }
-
     private fun populateLayout() {
         try {
             // read projects from state saved in ClientStatus
@@ -311,7 +318,8 @@ class ProjectsFragment : Fragment() {
             }
 
             // list adapter
-            dialogBinding.options.adapter = ProjectControlsListAdapter(activity!!, controls)
+            dialogBinding.options.adapter = ProjectControlsRecyclerViewAdapter(activity!!, controls)
+            dialogBinding.options.layoutManager = LinearLayoutManager(activity)
 
             Logging.logDebug(Logging.Category.USER_ACTION, "dialog list adapter entries: " + controls.size)
 
