@@ -1,7 +1,7 @@
 /*
  * This file is part of BOINC.
- * http://boinc.berkeley.edu
- * Copyright (C) 2021 University of California
+ * https://boinc.berkeley.edu
+ * Copyright (C) 2025 University of California
  *
  * BOINC is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License
@@ -203,14 +203,6 @@ class MonitorAsync(monitor: IMonitor?) : IMonitor {
         return monitor.showNotificationDuringSuspend
     }
 
-    override fun getWelcomeStateFile(): Boolean {
-        return monitor.welcomeStateFile
-    }
-
-    override fun setWelcomeStateFile() {
-        return monitor.setWelcomeStateFile()
-    }
-
     override fun quitClient(): Boolean {
         return monitor.quitClient()
     }
