@@ -18,7 +18,6 @@
  */
 package edu.berkeley.boinc.rpc
 
-import android.util.Log
 import android.util.Xml
 import edu.berkeley.boinc.utils.Logging
 import org.xml.sax.Attributes
@@ -166,10 +165,12 @@ class ProjectsParser : BaseParser() {
                     mProject.noCUDAPref = mCurrentElement.toString() != "0"
                 } else if (localName.equals(Project.Fields.NO_ATI_PREF, ignoreCase = true)) {
                     mProject.noATIPref = mCurrentElement.toString() != "0"
+                } else if (localName.equals(Project.Fields.DISK_USAGE, ignoreCase = true)) {
+                    mProject.diskUsage = mCurrentElement.toDouble()
                 }
             }
         } catch (e: Exception) {
-            Log.e(Logging.TAG, "ProjectsParser.endElement error: ", e)
+            Logging.logException(Logging.Category.XML, "ProjectsParser.endElement error: ", e)
         }
         mElementStarted = false
     }
@@ -190,8 +191,8 @@ class ProjectsParser : BaseParser() {
                 Xml.parse(rpcResult, parser)
                 parser.projects
             } catch (e: SAXException) {
-                Log.e(Logging.TAG, "ProjectsParser: malformed XML ", e)
-                Log.d(Logging.TAG, "ProjectsParser: $rpcResult")
+                Logging.logException(Logging.Category.RPC, "ProjectsParser: malformed XML ", e)
+                Logging.logDebug(Logging.Category.XML, "ProjectsParser: $rpcResult")
 
                 emptyList()
             }
