@@ -160,7 +160,7 @@ CLIENT_STATE::CLIENT_STATE()
     client_disk_usage = 0.0;
     total_disk_usage = 0.0;
 #ifdef ANDROID
-    device_status_time = 0;
+    device_status_time = dtime();
 #endif
 
     rec_interval_start = 0;
@@ -1180,8 +1180,13 @@ bool CLIENT_STATE::poll_slow_events() {
             }
             last_suspend_reason = suspend_reason;
         } else {
-            if (tasks_suspended && !tasks_throttled) {
-                resume_tasks(last_suspend_reason);
+            if (tasks_suspended) {
+                if (log_flags.task) {
+                    msg_printf(NULL, MSG_INFO, "Resuming computation");
+                }
+                if (!tasks_throttled) {
+                    resume_tasks(last_suspend_reason);
+                }
             }
         }
     } else if (first) {
