@@ -1251,6 +1251,9 @@ bool HOST_INFO::is_podman_VM_running() {
 bool HOST_INFO::get_docker_version_aux(DOCKER_TYPE type){
     char cmd[1024], buf[256];
 
+#ifdef __APPLE__
+    if (docker_cli_prog(type)[0] == '\0') return false;
+#endif
     snprintf(cmd, sizeof(cmd), "%s --version 2>/dev/null",
         docker_cli_prog(type)
     );
@@ -1844,12 +1847,14 @@ int HOST_INFO::get_host_info(bool init) {
     // a run of the client
     //
 
+#ifndef ANDROID
     if (!cc_config.dont_use_vbox) {
         get_virtualbox_version();
     }
 
     get_docker_version();
     get_docker_compose_version();
+#endif
 
     get_cpu_info();
     get_cpu_count();
@@ -2129,21 +2134,16 @@ inline long user_idle_time(struct utmp* u) {
 
 #if HAVE_XSS
 
-// Initializer for const vector<string> in xss_idle
+// return vector of X server names
 //
 const vector<string> X_display_values_initialize() {
     // According to "man Xserver", each local Xserver will have a socket file
     // at /tmp/.X11-unix/Xn, where "n" is the display number (0, 1, 2, etc).
     // We will parse this directory for currently open Xservers and attempt
-    // to ultimately query them for their idle time. If we can't open this
-    // directory, or the display_values vector is otherwise empty, then a
-    // static list of guesses for open display servers is utilized instead
-    // (DISPLAY values ":{0..6}") that will attempt connections to the first
-    // seven open Xservers.
+    // to ultimately query them for their idle time.
     //
-    // If we were unable to open _any_ Xserver, then we will log this and
-    // xss_idle returns true, effectively leaving idle detection up to other
-    // methods.
+    // If we are unable to open _any_ Xserver,
+    // idle detection is up to other methods.
     //
     static const string dir = "/tmp/.X11-unix/";
     vector<string> display_values;
@@ -2158,7 +2158,19 @@ const vector<string> X_display_values_initialize() {
             );
         }
     } else {
+        if (log_flags.idle_detection_debug ) {
+            msg_printf(NULL, MSG_INFO,
+                "[idle_detection] scanning %s",  dir.c_str()
+            );
+        }
         while ((dirp = readdir(dp)) != NULL) {
+            if (!strcmp(dirp->d_name, ".")) continue;
+            if (!strcmp(dirp->d_name, "..")) continue;
+            if (log_flags.idle_detection_debug ) {
+                msg_printf(NULL, MSG_INFO,
+                    "[idle_detection] found X server %s", dirp->d_name
+                );
+            }
             display_values.push_back(string(dirp->d_name));
         }
         closedir(dp);
@@ -2178,14 +2190,16 @@ const vector<string> X_display_values_initialize() {
     return display_values;
 }
 
-// Ask the X server for user idle time (using XScreenSaver API)
+// Ask X servers for user idle time (using XScreenSaver API)
 // Return min of idle times.
 // This function assumes that the boinc user has been
-// granted access to the Xservers a la "xhost +SI:localuser:boinc". If
-// access isn't available for an Xserver, then that Xserver is skipped.
+// granted access to the Xservers a la "xhost +SI:localuser:boinc".
+// If access isn't available for an Xserver, that Xserver is skipped.
 // One may drop a file in /etc/X11/Xsession.d/ that runs the xhost command
 // for all Xservers on a machine when the Xservers start up.
 //
+// TODO: call X_display_values_initialize() once, not once per second
+//
 long xss_idle() {
     long idle_time = USER_IDLE_TIME_INF;
     const vector<string> display_values = X_display_values_initialize();
@@ -2261,11 +2275,8 @@ long xss_idle() {
 
         if (log_flags.idle_detection_debug) {
             msg_printf(NULL, MSG_INFO,
-                "[idle_detection] XSS idle detection succeeded on display '%s'.",
-                it->c_str()
-            );
-            msg_printf(NULL, MSG_INFO,
-                "[idle_detection] display idle time: %ld sec", display_idle_time
+                "[idle_detection] XSS idle time on display '%s': %ld",
+                it->c_str(), display_idle_time
             );
         }
 
