@@ -1,6 +1,6 @@
 // This file is part of BOINC.
-// http://boinc.berkeley.edu
-// Copyright (C) 2022 University of California
+// https://boinc.berkeley.edu
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -13,7 +13,7 @@
 // See the GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
+// along with BOINC.  If not, see <https://www.gnu.org/licenses/>.
 
 // command-line version of the BOINC client
 
@@ -216,6 +216,13 @@ static void init_core_client(int argc, char** argv) {
             BOINC_DIAG_REDIRECTSTDOUT;
     }
 
+    // Win32 - detach from console if requested
+#ifdef _WIN32
+    if (gstate.detach_console) {
+        FreeConsole();
+    }
+#endif
+
     diagnostics_init(flags, "stdoutdae", "stderrdae");
 
 #ifdef _WIN32
@@ -231,7 +238,7 @@ static void init_core_client(int argc, char** argv) {
 #endif
 
     read_config_file(true);
-    
+
     // NOTE: this must be called BEFORE newer_version_startup_check()
     // Only branded builds of BOINC should have an nvc_config.xml file
     // in the BOINC Data directory. See comments in current_version.cpp.
@@ -239,13 +246,6 @@ static void init_core_client(int argc, char** argv) {
     if (read_nvc_config_file()) {
        // msg_printf(NULL, MSG_INFO, "nvc_config.xml not found - using defaults");
     }
-    
-    // Win32 - detach from console if requested
-#ifdef _WIN32
-    if (gstate.detach_console) {
-        FreeConsole();
-    }
-#endif
 
     // Unix: install signal handlers
 #ifndef _WIN32
@@ -260,17 +260,18 @@ static void init_core_client(int argc, char** argv) {
 #endif
 }
 
-// Some dual-GPU laptops (e.g., Macbook Pro) don't power down
-// the more powerful GPU until all applications which used them exit.
-// To save battery life, the client launches a second instance
-// of the client as a child process to detect and get info
-// about the GPUs.
-// The child process writes the info to a temp file which our main
-// client then reads.
+// detect GPUs and write a description of them (and error/warning messages)
+// to coproc_info.xml.
+//
+// We do this in a separate process for two reasons:
+// 1) GPU detection can crash even if we catch signals
+// 2) Some dual-GPU laptops (e.g., Macbook Pro) don't power down
+//  the more powerful GPU until all processes which used them exit.
+//  If we detected such GPUs in the client, they'd never power down.
 //
 static void do_gpu_detection(int argc, char** argv) {
     vector<string> warnings;
-    
+
     boinc_install_signal_handlers();
     gstate.parse_cmdline(argc, argv);
     gstate.now = dtime();
@@ -291,13 +292,64 @@ static void do_gpu_detection(int argc, char** argv) {
     warnings.clear();
 }
 
+//////// functions to prevent two clients from running on the same host
+
+#ifdef _WIN32
+static int get_client_mutex(const char*) {
+    char buf[MAX_PATH] = "";
+
+    // Global mutex on Win2k and later
+    //
+    safe_strcpy(buf, "Global\\");
+    safe_strcat(buf, RUN_MUTEX);
+
+    HANDLE h = CreateMutexA(NULL, true, buf);
+    if ((h==0) || (GetLastError() == ERROR_ALREADY_EXISTS)) {
+        return ERR_ALREADY_RUNNING;
+    }
+#else
+static int get_client_mutex(const char* dir) {
+    char path[MAXPATHLEN];
+    static FILE_LOCK file_lock;
+
+    snprintf(path, sizeof(path), "%s/%s", dir, LOCK_FILE_NAME);
+    path[sizeof(path)-1] = 0;
+
+    int retval = file_lock.lock(path);
+    if (retval == ERR_FCNTL) {
+        return ERR_ALREADY_RUNNING;
+    } else if (retval) {
+        return retval;
+    }
+#endif
+    return 0;
+}
+
+int wait_client_mutex(const char* dir, double timeout) {
+    double start = dtime();
+    int retval = 0;
+    while (1) {
+        retval = get_client_mutex(dir);
+        if (!retval) return 0;
+        boinc_sleep(1);
+        if (dtime() - start > timeout) break;
+    }
+    return retval;
+}
+
 static int initialize() {
     int retval;
 
     if (!cc_config.allow_multiple_clients) {
         retval = wait_client_mutex(".", 10);
         if (retval) {
-            log_message_error("Another instance of BOINC is running.");
+            if (retval == ERR_ALREADY_RUNNING) {
+                log_message_error("Another instance of BOINC is running.");
+            } else if (retval == ERR_OPEN) {
+                log_message_error("Failed to open lockfile. Check file/directory permissions.");
+            } else {
+                log_message_error("Failed to lock directory.", retval);
+            }
             return ERR_EXEC;
         }
     }
@@ -381,6 +433,7 @@ int boinc_main_loop() {
 
     log_message_startup("Initialization completed");
 
+    // client main loop; poll interval is 1 sec
     while (1) {
         if (!gstate.poll_slow_events()) {
             gstate.do_io_or_sleep(POLL_INTERVAL);
@@ -409,6 +462,7 @@ int boinc_main_loop() {
                 break;
             }
         }
+        gstate.check_overdue();
     }
 
     return finalize();
@@ -440,11 +494,6 @@ int main(int argc, char** argv) {
             return 0;
         }
 
-        if (!strcmp(argv[index], "--run_test_app")) {
-            read_config_file(true);
-            run_test_app();
-        }
-
 #ifdef _WIN32
         // This bit of silliness is required to properly detach when run from within a command
         // prompt under Win32.  The root cause of the problem is that CMD.EXE does not return
