@@ -80,20 +80,20 @@ struct RR_SIM {
     inline void activate(RESULT* rp) {
         PROJECT* p = rp->project;
         active_jobs.push_back(rp);
-        int rt = rp->avp->gpu_usage.rsc_type;
+        int rt = rp->resource_usage.rsc_type;
 
         // if this is a GPU app and GPU computing is suspended,
         // don't count its CPU usage.
         // That way we'll fetch more CPU work if needed.
         //
         if (!rt || !gpu_suspend_reason) {
-            rsc_work_fetch[0].sim_nused += rp->avp->avg_ncpus;
-            p->rsc_pwf[0].sim_nused += rp->avp->avg_ncpus;
+            rsc_work_fetch[0].sim_nused += rp->resource_usage.avg_ncpus;
+            p->rsc_pwf[0].sim_nused += rp->resource_usage.avg_ncpus;
         }
 
         if (rt) {
-            rsc_work_fetch[rt].sim_nused += rp->avp->gpu_usage.usage;
-            p->rsc_pwf[rt].sim_nused += rp->avp->gpu_usage.usage;
+            rsc_work_fetch[rt].sim_nused += rp->resource_usage.coproc_usage;
+            p->rsc_pwf[rt].sim_nused += rp->resource_usage.coproc_usage;
             if (rsc_work_fetch[rt].has_exclusions) {
                 set_bits(
                     rp->app->non_excluded_instances[rt],
@@ -111,12 +111,6 @@ struct RR_SIM {
         }
         if (have_max_concurrent) {
             max_concurrent_inc(rp);
-            if (p->rsc_pwf[0].sim_nused > p->rsc_pwf[0].max_nused) {
-                p->rsc_pwf[0].max_nused = p->rsc_pwf[0].sim_nused;
-            }
-            if (rt && p->rsc_pwf[rt].sim_nused > p->rsc_pwf[rt].max_nused) {
-                p->rsc_pwf[rt].max_nused = p->rsc_pwf[rt].sim_nused;
-            }
         }
     }
 
@@ -136,11 +130,11 @@ void set_rrsim_flops(RESULT* rp) {
     // For coproc jobs, use app version estimate
     //
     if (rp->uses_gpu()) {
-        rp->rrsim_flops = rp->avp->flops * gstate.overall_gpu_frac();
+        rp->rrsim_flops = rp->resource_usage.flops * gstate.overall_gpu_frac();
     } else if (rp->avp->needs_network) {
-        rp->rrsim_flops =  rp->avp->flops * gstate.overall_cpu_and_network_frac();
+        rp->rrsim_flops =  rp->resource_usage.flops * gstate.overall_cpu_and_network_frac();
     } else {
-        rp->rrsim_flops =  rp->avp->flops * gstate.overall_cpu_frac();
+        rp->rrsim_flops =  rp->resource_usage.flops * gstate.overall_cpu_frac();
     }
     if (rp->rrsim_flops == 0) {
         rp->rrsim_flops = 1e6;      // just in case
@@ -201,11 +195,11 @@ void RR_SIM::init_pending_lists() {
 
         PROJECT* p = rp->project;
         p->pwf.n_runnable_jobs++;
-        p->rsc_pwf[0].nused_total += rp->avp->avg_ncpus;
+        p->rsc_pwf[0].nused_total += rp->resource_usage.avg_ncpus;
         set_rrsim_flops(rp);
-        int rt = rp->avp->gpu_usage.rsc_type;
+        int rt = rp->resource_usage.rsc_type;
         if (rt) {
-            p->rsc_pwf[rt].nused_total += rp->avp->gpu_usage.usage;
+            p->rsc_pwf[rt].nused_total += rp->resource_usage.coproc_usage;
             p->rsc_pwf[rt].n_runnable_jobs++;
             p->rsc_pwf[rt].queue_est += rp->rrsim_flops_left/rp->rrsim_flops;
         }
@@ -413,13 +407,13 @@ static void handle_missed_deadline(RESULT* rpbest, double diff, double ar) {
         }
     } else {
         rpbest->rr_sim_misses_deadline = true;
-        int rt = rpbest->avp->gpu_usage.rsc_type;
+        int rt = rpbest->resource_usage.rsc_type;
         if (rt) {
             pbest->rsc_pwf[rt].deadlines_missed++;
-            rsc_work_fetch[rt].deadline_missed_instances += rpbest->avp->gpu_usage.usage;
+            rsc_work_fetch[rt].deadline_missed_instances += rpbest->resource_usage.coproc_usage;
         } else {
             pbest->rsc_pwf[0].deadlines_missed++;
-            rsc_work_fetch[0].deadline_missed_instances += rpbest->avp->avg_ncpus;
+            rsc_work_fetch[0].deadline_missed_instances += rpbest->resource_usage.avg_ncpus;
         }
         if (log_flags.rr_simulation) {
             msg_printf(pbest, MSG_INFO,
@@ -438,9 +432,11 @@ static void mc_update_stats(double sim_now, double dt, double buf_end) {
         if (!p->app_configs.project_has_mc) continue;
         for (int rt=0; rt<coprocs.n_rsc; rt++) {
             RSC_PROJECT_WORK_FETCH& rsc_pwf = p->rsc_pwf[rt];
-            RSC_WORK_FETCH& rwf = rsc_work_fetch[rt];
-            double x = rsc_pwf.max_nused - rsc_pwf.sim_nused;
-            x = std::min(x, rwf.ninstances - rwf.sim_nused);
+
+            // x is the number of instances this project isn't using but could
+            // (given MC constraints)
+            //
+            double x = rsc_pwf.mc_max_could_use - rsc_pwf.sim_nused;
             if (x > 1e-6 && sim_now < buf_end) {
                 double dt2;
                 if (sim_now + dt > buf_end) {
@@ -565,10 +561,10 @@ void RR_SIM::simulate() {
                 //
                 double frac = rpbest->uses_gpu()?gstate.overall_gpu_frac():gstate.overall_cpu_frac();
                 double dur = rpbest->estimated_runtime_remaining() / frac;
-                rsc_work_fetch[0].update_busy_time(dur, rpbest->avp->avg_ncpus);
-                int rt = rpbest->avp->gpu_usage.rsc_type;
+                rsc_work_fetch[0].update_busy_time(dur, rpbest->resource_usage.avg_ncpus);
+                int rt = rpbest->resource_usage.rsc_type;
                 if (rt) {
-                    rsc_work_fetch[rt].update_busy_time(dur, rpbest->avp->gpu_usage.usage);
+                    rsc_work_fetch[rt].update_busy_time(dur, rpbest->resource_usage.coproc_usage);
                 }
             }
         }
@@ -686,33 +682,35 @@ void rr_simulation(const char* why) {
 }
 
 // Compute the number resources with > 0 idle instance
-// Put results in global state (rsc_work_fetch)
+// Put results in global state (rsc_work_fetch[].nidle_now)
 // This is called from the account manager logic,
 // to decide if we need to get new projects from the AM.
 //
 int n_idle_resources() {
-    int nidle_rsc = coprocs.n_rsc;
+    int nidle_rsc = 0;
+    coprocs.coprocs[0].count = gstate.n_usable_cpus;
     for (int i=0; i<coprocs.n_rsc; i++) {
-        rsc_work_fetch[i].nidle_now = coprocs.coprocs[i].count;
+        int c = coprocs.coprocs[i].count;
+        rsc_work_fetch[i].nidle_now = c;
+        if (c > 0) nidle_rsc++;
     }
     for (unsigned int i=0; i<gstate.results.size(); i++) {
         RESULT* rp = gstate.results[i];
         if (!rp->nearly_runnable()) continue;
         if (rp->some_download_stalled()) continue;
-        APP_VERSION* avp = rp->avp;
         if (rsc_work_fetch[0].nidle_now) {
-            rsc_work_fetch[0].nidle_now -= avp->avg_ncpus;
+            rsc_work_fetch[0].nidle_now -= rp->resource_usage.avg_ncpus;
             if (rsc_work_fetch[0].nidle_now <= 0) {
                 nidle_rsc--;
                 rsc_work_fetch[0].nidle_now = 0;
             }
         }
-        int j = avp->gpu_usage.rsc_type;
+        int j = rp->resource_usage.rsc_type;
         if (!j) {
             continue;
         }
         if (rsc_work_fetch[j].nidle_now) {
-            rsc_work_fetch[j].nidle_now -= avp->gpu_usage.usage;
+            rsc_work_fetch[j].nidle_now -= rp->resource_usage.coproc_usage;
             if (rsc_work_fetch[j].nidle_now <= 0) {
                 nidle_rsc--;
                 rsc_work_fetch[j].nidle_now = 0;
