@@ -25,7 +25,7 @@
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include <errno.h>
-#include <fcntl.h> 
+#include <fcntl.h>
 #include <unistd.h>
 #include <grp.h>
 #include <pwd.h>
@@ -48,10 +48,10 @@ bool g_use_sandbox = false;
 
 #ifndef _WIN32
 
-// POSIX requires that shells run from an application will use the 
-// real UID and GID if different from the effective UID and GID.  
-// Mac OS 10.4 did not enforce this, but OS 10.5 does.  Since 
-// system() invokes a shell, we can't use it to run the switcher 
+// POSIX requires that shells run from an application will use the
+// real UID and GID if different from the effective UID and GID.
+// Mac OS 10.4 did not enforce this, but OS 10.5 does.  Since
+// system() invokes a shell, we can't use it to run the switcher
 // or setprojectgrp utilities, so we must do a fork() and execv().
 //
 int switcher_exec(const char *util_filename, const char* cmdline) {
@@ -75,7 +75,7 @@ int switcher_exec(const char *util_filename, const char* cmdline) {
         perror("pipe() for fds_out failed in switcher_exec");
         return ERR_PIPE;
     }
-    
+
     if (pipe(fds_err) == -1) {
         perror("pipe() for fds_err failed in switcher_exec");
         return ERR_PIPE;
@@ -104,10 +104,10 @@ int switcher_exec(const char *util_filename, const char* cmdline) {
     // Parent only needs one-way (read) pipes so close write pipes
     close(fds_out[1]);
     close(fds_err[1]);
-    
+
     // Capture stdout output
     while (1) {
-        ssize_t count = read(fds_out[0], buffer, sizeof(buffer));
+        ssize_t count = read(fds_out[0], buffer, sizeof(buffer)-1);
         if (count == -1) {
             if (errno == EINTR) {
                 continue;
@@ -124,7 +124,7 @@ int switcher_exec(const char *util_filename, const char* cmdline) {
 
     // Capture stderr output
     while (1) {
-        ssize_t count = read(fds_err[0], buffer, sizeof(buffer));
+        ssize_t count = read(fds_err[0], buffer, sizeof(buffer)-1);
         if (count == -1) {
             if (errno == EINTR) {
                 continue;
@@ -167,10 +167,10 @@ int switcher_exec(const char *util_filename, const char* cmdline) {
 
 int kill_via_switcher(int pid) {
     char cmd[1024];
-    
+
     if (!g_use_sandbox) return 0;
 
-    // if project application is running as user boinc_project and 
+    // if project application is running as user boinc_project and
     // client is running as user boinc_master,
     // we cannot send a signal directly, so use switcher.
     //
@@ -186,7 +186,7 @@ static int lookup_group(const char* name, gid_t& gid) {
 }
 
 int remove_project_owned_file_or_dir(const char* path) {
-    char cmd[1024];
+    char cmd[5120];
 
     if (g_use_sandbox) {
         snprintf(cmd, sizeof(cmd), "/bin/rm rm -fR \"%s\"", path);
@@ -202,7 +202,7 @@ int remove_project_owned_file_or_dir(const char* path) {
 int get_project_gid() {
     if (g_use_sandbox) {
 #ifdef _DEBUG
-        // GDB can't attach to applications which are running as a different user   
+        // GDB can't attach to applications which are running as a different user
         //  or group, so fix up data with current user and group during debugging
         gstate.boinc_project_gid = getegid();
 #else
@@ -214,23 +214,27 @@ int get_project_gid() {
     return 0;
 }
 
-// Graphics apps called by screensaver or Manager (via Show 
+// Graphics apps called by screensaver or Manager (via Show
 // Graphics button) now write files in their slot directory as
-// the logged in user, not boinc_master. This ugly hack uses 
+// the logged in user, not boinc_master. This ugly hack uses
 // setprojectgrp to fix all ownerships in this slot directory.
-int fix_slot_owners(const int slot){
 #ifdef __APPLE__
+int fix_slot_owners(const int slot){
     char relative_path[100];
     char full_path[MAXPATHLEN];
-    
+
     if (g_use_sandbox) {
         snprintf(relative_path, sizeof(relative_path), "slots/%d", slot);
         realpath(relative_path, full_path);
         fix_owners_in_directory(full_path);
     }
-#endif
     return 0;
 }
+#else
+int fix_slot_owners(const int){
+    return 0;
+}
+#endif
 
 int fix_owners_in_directory(char* dir_path) {
     char item_path[MAXPATHLEN];
@@ -243,7 +247,7 @@ int fix_owners_in_directory(char* dir_path) {
     uid_t boinc_master_uid = -1;
     uid_t boinc_project_uid = -1;
     gid_t boinc_project_gid = -1;
-    
+
     pw = getpwnam(BOINC_MASTER_USER_NAME);
     if (pw == NULL) return -1;
     boinc_master_uid = pw->pw_uid;
@@ -251,7 +255,7 @@ int fix_owners_in_directory(char* dir_path) {
     pw = getpwnam(BOINC_PROJECT_USER_NAME);
     if (pw == NULL) return -1;
     boinc_project_uid = pw->pw_uid;
-    
+
     lookup_group(BOINC_PROJECT_GROUP_NAME, boinc_project_gid);
 
     dirp = opendir(dir_path);
