@@ -1,6 +1,6 @@
 // This file is part of BOINC.
-// http://boinc.berkeley.edu
-// Copyright (C) 2023 University of California
+// https://boinc.berkeley.edu
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -76,7 +76,7 @@ BEGIN_EVENT_TABLE(CTaskBarIcon, wxTaskBarIconEx)
 END_EVENT_TABLE()
 
 
-CTaskBarIcon::CTaskBarIcon(wxString title, wxIconBundle* icon, wxIconBundle* iconDisconnected, wxIconBundle* iconSnooze
+CTaskBarIcon::CTaskBarIcon(wxIconBundle* icon, wxIconBundle* iconDisconnected, wxIconBundle* iconSnooze
 #ifdef __WXMAC__
 , wxTaskBarIconType iconType
 #endif
@@ -420,6 +420,7 @@ wxMenu *CTaskBarIcon::CreatePopupMenu() {
     return menu;
 }
 
+
 // Override the standard wxTaskBarIcon::SetIcon() because we are only providing a
 // 16x16 icon for the menubar, while the Dock needs a 128x128 icon.
 // Rather than using an entire separate icon, overlay the Dock icon with a badge
@@ -465,42 +466,43 @@ bool CTaskBarIcon::SetIcon(const wxIcon& icon, const wxString& )
         return true;
     }
 
-    // Convert the wxImage into a wxBitmap so we can perform some
-    // wxBitmap operations with it
-    macIcon.InitAlpha();
-    wxBitmap bmp( macIcon ) ;
+    unsigned char* iconBuffer = macIcon.GetData();
 
-    // wxMac's XMP image format always uses 32-bit pixels but allows only
-    // 1-bit masks, so we use a separate XMP file for the 8-bit mask to
-    // allow us to do proper anti-aliasing of the badges.  This code assumes
-    // that all badges are the same size circle and at the same position so
-    // that they can share a single mask.
-    wxBitmap mask_bmp( macbadgemask ) ;
-    h = bmp.GetHeight();
-    w = bmp.GetWidth();
-
-    wxASSERT(h == mask_bmp.GetHeight());
-    wxASSERT(w == mask_bmp.GetWidth());
-
-    unsigned char * iconBuffer = (unsigned char *)bmp.GetRawAccess();
-    unsigned char * maskBuffer = (unsigned char *)mask_bmp.GetRawAccess() + 1;
+    wxImage mac_badge_mask = wxImage(macbadgemask);
+    unsigned char* maskBuffer = mac_badge_mask.GetData();
+    h = macIcon.GetHeight();
+    w = macIcon.GetWidth();
+    wxASSERT(h == mac_badge_mask.GetHeight());
+    wxASSERT(w == mac_badge_mask.GetWidth());
 
+    void * maskedIconData = malloc(h*w*4);
+    unsigned char * maskedIconDataChars = (unsigned char*)maskedIconData;
     for (y=0; y<h; y++) {
         for (x=0; x<w; x++) {
-            *iconBuffer = 255 - *maskBuffer;
-            iconBuffer += 4;
-            maskBuffer += 4;
+            *maskedIconDataChars++ = *iconBuffer++;
+            *maskedIconDataChars++ = *iconBuffer++;
+            *maskedIconDataChars++ = *iconBuffer++;
+            *maskedIconDataChars++ = 255 - *maskBuffer;
+            maskBuffer += 3;
         }
     }
 
+    wxImage maskedIcon = wxImage(w, h);
+    maskedIcon.SetDataRGBA((unsigned char*)maskedIconData);
+    wxBitmap bmp = wxBitmap(maskedIcon);
+    if (!bmp.IsOk()) {
+        return false;
+    }
+
     // Actually set the dock image
 #if wxDEBUG_LEVEL
     err =
 #endif
     SetDockBadge(&bmp);
 
+#if wxDEBUG_LEVEL
     wxASSERT(err == 0);
-
+#endif
     return true;
 }
 
