@@ -1,6 +1,6 @@
 // This file is part of BOINC.
-// http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// https://boinc.berkeley.edu
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -13,7 +13,7 @@
 // See the GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
+// along with BOINC.  If not, see <https://www.gnu.org/licenses/>.
 //
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "CompletionErrorPage.h"
@@ -107,7 +107,7 @@ void CCompletionErrorPage::CreateControls()
 
     m_pTitleStaticCtrl = new wxStaticText;
     m_pTitleStaticCtrl->Create( itemWizardPage85, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
-    m_pTitleStaticCtrl->SetFont(wxFont(12, wxSWISS, wxNORMAL, wxBOLD, FALSE, _T("Verdana")));
+    m_pTitleStaticCtrl->SetFont(wxFont(12, wxFONTFAMILY_SWISS, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD, FALSE, _T("Verdana")));
     itemBoxSizer86->Add(m_pTitleStaticCtrl, 0, wxALIGN_LEFT|wxALL, 5);
 
     itemBoxSizer86->Add(5, 5, 0, wxALIGN_LEFT|wxALL, 5);
@@ -233,6 +233,9 @@ void CCompletionErrorPage::OnPageChanged( wxWizardExEvent& event ) {
         m_pServerMessagesDescriptionCtrl->SetLabel(
             _("Messages from server:")
         );
+        const wxSize page_width = this->GetClientSize();
+        const int minimum_size = page_width.x - 15;  // 15 seems to be needed to keep the right border visible.
+        m_pServerMessagesCtrl->Wrap(minimum_size);
         m_pServerMessagesDescriptionCtrl->Show();
         m_pServerMessagesCtrl->Show();
     }
