@@ -1,6 +1,6 @@
 // This file is part of BOINC.
-// http://boinc.berkeley.edu
-// Copyright (C) 2023 University of California
+// https://boinc.berkeley.edu
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -616,7 +616,9 @@ bool CDlgOptions::ReadSettings() {
     CMainDocument*      pDoc = wxGetApp().GetDocument();
     CBOINCBaseFrame*    pFrame = wxGetApp().GetFrame();
     wxString            strBuffer = wxEmptyString;
+#ifdef __WXMSW__
     wxArrayString       astrDialupConnections;
+#endif
 
     wxASSERT(pDoc);
     wxASSERT(pFrame);
