@@ -1,6 +1,6 @@
 // This file is part of BOINC.
-// http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// https://boinc.berkeley.edu
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -90,9 +90,6 @@ public:
     virtual bool HasTransparentBackground() { return true; };
 
     virtual void OnEraseBackground(wxEraseEvent& /*event*/) {};
-#ifndef __WXMAC__
-    virtual void OnPaint(wxPaintEvent& event);
-#endif
 
     DECLARE_EVENT_TABLE()
 };
