@@ -449,7 +449,6 @@ CSimpleTaskPanel::CSimpleTaskPanel() {
 CSimpleTaskPanel::CSimpleTaskPanel( wxWindow* parent ) :
     CSimplePanelBase( parent )
 {
-    wxSize sz;
     int w, h;
     wxString str = wxEmptyString;
 
@@ -764,6 +763,10 @@ void CSimpleTaskPanel::ReskinInterface() {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleTaskPanel::ReskinInterface - Function Begin"));
     CSimplePanelBase::ReskinInterface();
     m_SlideShowArea->AdvanceSlideShow(false, false);
+#ifdef __WXMAC__
+    m_TaskSelectionCtrl->Show();
+    m_myTasksLabel->Show();
+#endif
     UpdateTaskSelectionList(true);
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleTaskPanel::ReskinInterface - Function Begin"));
 }
