@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2020 University of California
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -43,7 +43,9 @@
 - (IBAction)closeSheetCancel:(id) sender;
 
 - (bool) setUpToUseCGWindowList;
+- (void) cleanupSaver:(bool)mayExit;
 - (void) doPeriodicTasks;
+- (void) advancePosition:(NSTimer*)timer;
 
 @end
 
@@ -51,8 +53,10 @@
 
 @property (NS_NONATOMIC_IOSONLY, readonly) GLuint currentTextureName;
 - (void)init:(NSView*)saverView;
-- (void)portDied:(NSNotification *)notification;
 - (void)testConnection;
+- (void)portDied:(NSNotification *)notification;
+- (void)closeServerPort;
+- (void)cleanUpOpenGL;
 
 @end
 
@@ -77,20 +81,22 @@ int             startBOINCSaver(void);
 int             getSSMessage(char **theMessage, int* coveredFreq);
 void            windowIsCovered();
 void            drawPreview(CGContextRef myContext);
+void            stopAllGFXApps(void);
 void            closeBOINCSaver(void);
 void            setDefaultDisplayPeriods(void);
 bool            getShow_default_ss_first();
 double          getGFXDefaultPeriod();
 double          getGFXSciencePeriod();
 double          getGGFXChangePeriod();
-void            incompatibleGfxApp(char * appPath, pid_t pid, int slot);
+void            incompatibleGfxApp(char * appPath, char * wuName, pid_t pid, int slot);
 void            setShow_default_ss_first(bool value);
 void            setGFXDefaultPeriod(double value);
 void            setGFXSciencePeriod(double value);
 void            setGGFXChangePeriod(double value);
 double          getDTime();
 void            doBoinc_Sleep(double seconds);
-void            launchedGfxApp(char * appPath, pid_t thePID, int slot);
+void            launchedGfxApp(char * appPath, char * wuName, pid_t thePID, int slot);
+int             compareBOINCLibVersionTo(int toMajor, int toMinor, int toRelease);
 void            print_to_log_file(const char *format, ...);
 void            strip_cr(char *buf);
 void            PrintBacktrace(void);
@@ -98,6 +104,10 @@ void            PrintBacktrace(void);
 extern bool     gIsCatalina;
 extern bool     gIsHighSierra;
 extern bool     gIsMojave;
+extern bool     gIsSonoma;
+extern bool     gMach_bootstrap_unavailable_to_screensavers;
+extern mach_port_name_t commsPort;
+
 
 #ifdef __cplusplus
 }    // extern "C"
