@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2022 University of California
+// Copyright (C) 2025 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -100,15 +100,20 @@ static io_connect_t GPUSelectConnect = IO_OBJECT_NULL;
 static bool OKToRunOnBatteries = false;
 static bool RunningOnBattery = true;
 static time_t ScreenSaverStartTime = 0;
-static bool ScreenIsBlanked = false;
+bool ScreenIsBlanked = false;
 static int retryCount = 0;
 static pthread_mutexattr_t saver_mutex_attr;
 pthread_mutex_t saver_mutex;
 static char passwd_buf[256];
 char gUserName[64];
-bool gIsHighSierra = false;  // OS 10.13 or later
+bool gIsHighSierra = false; // OS 10.13 or later
 bool gIsMojave = false;     // OS 10.14 or later
 bool gIsCatalina = false;   // OS 10.15 or later
+bool gIsSonoma = false;     // OS 14.0 or later
+
+// As of MacOS 14.0, the legacyScreenSave sandbox
+// prevents using bootstrap_look_up.
+bool gMach_bootstrap_unavailable_to_screensavers = false;
 
 const char *  CantLaunchCCMsg = "Unable to launch BOINC application.";
 const char *  LaunchingCCMsg = "Launching BOINC application.";
@@ -126,6 +131,7 @@ const char *  CCNotRunningMsg = "BOINC is not running.";
 
 //const char *  BOINCExitedSaverMode = "BOINC is no longer in screensaver mode.";
 
+static bool created = false;    // CAF
 
 // If there are multiple displays, this may get called
 // multiple times (once for each display), so we need to guard
@@ -139,9 +145,19 @@ void initBOINCSaver() {
         "stdoutscr", "stderrscr"
         );
 
+    // When gfx_cleanup exits, it will send a SIGCHLD to legacysceensaver
+    // which is normally set to also exit when it receives that signal
+    struct sigaction temp;
+    sigaction(SIGCHLD, NULL, &temp);
+    temp.sa_handler = SIG_IGN;
+    sigaction(SIGCHLD, &temp, NULL);
+
+for (int i=1; i<NSIG; ++i)
+boinc_set_signal_handler(i, boinc_catch_signal);
     if (gspScreensaver == NULL) {
         gspScreensaver = new CScreensaver();
-    }
+        created = false;    // CAF
+   }
 }
 
 
@@ -151,7 +167,10 @@ int startBOINCSaver() {
     IsDualGPUMacbook = true;
 #endif
     if (gspScreensaver) {
-        return gspScreensaver->Create();
+        if (!created) {     // CAF
+            created = true; // CAF
+            return gspScreensaver->Create();
+        }                   // CAF
     }
     return TEXTLOGOFREQUENCY;
 }
@@ -182,6 +201,13 @@ void drawPreview(CGContextRef myContext) {
 };
 
 
+void stopAllGFXApps() {
+    if (gspScreensaver) {
+        gspScreensaver->Shared_Offscreen_Buffer_Unavailable();
+    }
+}
+
+
 // If there are multiple displays, this may get called
 // multiple times (once for each display), so we need to guard
 // against any problems that may cause.
@@ -191,10 +217,12 @@ void closeBOINCSaver() {
         delete gspScreensaver;
         gspScreensaver = NULL;
     }
+for (int i=1; i<32; ++i)
+boinc_set_signal_handler(i, boinc_catch_signal);
 }
 
 
-void incompatibleGfxApp(char * appPath, pid_t pid, int slot){
+void incompatibleGfxApp(char * appPath, char * wuName, pid_t pid, int slot){
     char *p;
     static char buf[1024];
     static double msgstartTime = 0.0;
@@ -240,8 +268,8 @@ void incompatibleGfxApp(char * appPath, pid_t pid, int slot){
         }   // End if (msgstartTime == 0.0)
 
         if (msgstartTime && (getDTime() - msgstartTime > 5.0)) {
-            gspScreensaver->markAsIncompatible(appPath);
-            launchedGfxApp("", 0, -1);
+            gspScreensaver->markAsIncompatible(wuName);
+            launchedGfxApp("", "", 0, -1);
             msgstartTime = 0.0;
             gspScreensaver->terminate_v6_screensaver(pid);
         }
@@ -343,7 +371,6 @@ CScreensaver::CScreensaver() {
     GetDefaultDisplayPeriods(periods);
     m_bShow_default_ss_first = periods.Show_default_ss_first;
 
-
     m_fGFXDefaultPeriod = periods.GFXDefaultPeriod;
     m_fGFXSciencePeriod = periods.GFXSciencePeriod;
     m_fGFXChangePeriod = periods.GFXChangePeriod;
@@ -358,8 +385,12 @@ CScreensaver::CScreensaver() {
 }
 
 
+CScreensaver::~CScreensaver() {
+}
+
+
 int CScreensaver::Create() {
-        // Ugly workaround for a problem with the System Preferences app
+    // Ugly workaround for a problem with the System Preferences app
     // For an unknown reason, when this screensaver is run using the
     // Test button in the System Prefs Screensaver control panel, the
     // control panel calls our stopAnimation function as soon as the
@@ -400,14 +431,14 @@ int CScreensaver::Create() {
         strlcpy(m_gfx_Cleanup_Path, "\"", sizeof(m_gfx_Cleanup_Path));
         strlcat(m_gfx_Cleanup_Path, m_gfx_Switcher_Path, sizeof(m_gfx_Cleanup_Path));
         strlcat(m_gfx_Switcher_Path, "/gfx_switcher", sizeof(m_gfx_Switcher_Path));
-        strlcat(m_gfx_Cleanup_Path, "/gfx_cleanup\"", sizeof(m_gfx_Switcher_Path));
-
+        strlcat(m_gfx_Cleanup_Path, "/gfx_cleanup\"", sizeof(m_gfx_Cleanup_Path));
         // Launch helper app to work around a bug in OS 10.15 Catalina to
         // kill current graphics app if ScreensaverEngine exits without
         // first calling [ScreenSaverView stopAnimation]
         //TODO: Should we use this on OS 10.13+ ?
-        m_gfx_Cleanup_IPC = popen(m_gfx_Cleanup_Path, "w");
-
+        if (!m_gfx_Cleanup_IPC) {
+            m_gfx_Cleanup_IPC = popen(m_gfx_Cleanup_Path, "w");
+        }
         initBOINCApp();
 
         CGDisplayHideCursor(kCGNullDirectDisplay);
@@ -556,7 +587,7 @@ int CScreensaver::getSSMessage(char **theMessage, int* coveredFreq) {
             // Wait 1 second to allow ScreenSaver engine to close us down
             if (++gQuitCounter > (m_MessageText[0] ? TEXTLOGOFREQUENCY : NOTEXTLOGOFREQUENCY)) {
                 closeBOINCSaver();
-                KillScreenSaver(); // Stop the ScreenSaver Engine
+                exit(0);    // Stop the ScreenSaver Engine
             }
             break;
 #endif
@@ -657,9 +688,21 @@ void CScreensaver::drawPreview(CGContextRef myContext) {
 }
 
 
+void CScreensaver::Shared_Offscreen_Buffer_Unavailable() {
+    DestroyDataManagementThread();  // Kills current GFX app
+}
+
+
 void CScreensaver::ShutdownSaver() {
     DestroyDataManagementThread();
 
+    if (m_gfx_Cleanup_IPC) {
+        fprintf(m_gfx_Cleanup_IPC, "Quit\n");
+        fflush(m_gfx_Cleanup_IPC);
+        pclose(m_gfx_Cleanup_IPC);
+        m_gfx_Cleanup_IPC = NULL;
+    }
+
     if (rpc) {
 #if 0       // OS X calls closeBOINCSaver() when energy saver puts display
             // to sleep, but we want to keep crunching.  So don't kill it.
@@ -672,6 +715,7 @@ void CScreensaver::ShutdownSaver() {
             rpc->quit();    // Kill core client if we launched it
         }
 #endif
+        rpc->close();
         delete rpc;
         rpc = NULL;
     }
@@ -684,11 +728,8 @@ void CScreensaver::ShutdownSaver() {
     m_bQuitDataManagementProc = false;
     saverState = SaverState_Idle;
     retryCount = 0;
-    if (m_gfx_Cleanup_IPC) {
-        fprintf(m_gfx_Cleanup_IPC, "Quit\n");
-        fflush(m_gfx_Cleanup_IPC);
-        pclose(m_gfx_Cleanup_IPC);
-    }
+    ScreenSaverStartTime = 0;
+    ScreenIsBlanked = false;
 }
 
 
@@ -770,7 +811,6 @@ bool CScreensaver::DestroyDataManagementThread() {
         }
         boinc_sleep(0.1);
     }
-
     m_hDataManagementThread = NULL; // Don't delay more if this routine is called again.
 
     if (m_hGraphicsApplication) {
@@ -885,18 +925,6 @@ pid_t CScreensaver::getClientPID() {
 }
 
 
-// Send a Quit AppleEvent to the process which called this module
-// (i.e., tell the ScreenSaver engine to quit)
-int CScreensaver::KillScreenSaver() {
-    pid_t                       thisPID;
-    int                         retval;
-
-    thisPID = getpid();
-    retval = kill(thisPID, SIGABRT);   // SIGINT
-    return retval;
-}
-
-
 bool CScreensaver::Host_is_running_on_batteries() {
 #if SIMULATE_AC_BATTERY_SWITCHING
     // Simulate 30 seconds on AC, 30 on battery, 30 AC, 30 battery, etc.
@@ -1011,14 +1039,9 @@ void CScreensaver::CheckDualGPUPowerSource() {
 void print_to_log_file(const char *format, ...) {
 #if CREATE_LOG
     va_list args;
-    char buf[256];
     time_t t;
 #if USE_SPECIAL_LOG_FILE
-    safe_strcpy(buf, "/Users/");
-    safe_strcat(buf, getlogin());
-    safe_strcat(buf, "/Documents/test_log.txt");
-    FILE *f;
-    f = fopen(buf, "a");
+    FILE *f = fopen("/Users/Shared/test_log_BOINCSaver.txt", "a");   // CAF
     if (!f) return;
 
 //  freopen(buf, "a", stdout);
@@ -1059,7 +1082,50 @@ void strip_cr(char *buf)
 }
 #endif	// CREATE_LOG
 
-void PrintBacktrace(void) {
-// Dummy routine to satisfy linker
-}
+#include "QCrashReport.h"
 
+void PrintBacktrace(void) {
+// We need this special version of PrintBacktrace because
+// mac_backtrace.cpp doesn't work with screensavr sandbox limitatons
+#define CALL_STACK_SIZE 128
+    typedef int     (*backtraceProc)(void**,int);
+    typedef char ** (*backtrace_symbolsProc)(void* const*,int);
+    QCrashReportRef             crRef = NULL;
+
+    int                         frames, i;
+    void                        *systemlib = NULL;
+    void                        *callstack[CALL_STACK_SIZE];
+    char                        **symbols = NULL;
+    char                        outBuf[1024];
+    backtraceProc               myBacktraceProc = NULL;
+    backtrace_symbolsProc       myBacktrace_symbolsProc = NULL;
+
+    QCRCreateFromSelf(&crRef);
+
+    systemlib = dlopen ("/usr/lib/libSystem.dylib", RTLD_NOW );
+    if (systemlib) {
+        myBacktraceProc = (backtraceProc)dlsym(systemlib, "backtrace");
+     }
+    if (! myBacktraceProc) {
+        fprintf(stderr, "no myBacktraceProc\n");
+        return;    // Should never happen
+    }
+    frames = myBacktraceProc(callstack, CALL_STACK_SIZE);
+    myBacktrace_symbolsProc = (backtrace_symbolsProc)dlsym(systemlib, "backtrace_symbols");
+    if (myBacktrace_symbolsProc) {
+        symbols = myBacktrace_symbolsProc(callstack, frames);
+    }
+
+    for (i=0; i<frames; i++) {
+        strlcpy(outBuf, symbols[i], sizeof(outBuf));
+        fprintf(stderr, "%s\n", outBuf);
+    }
+    fprintf(stderr, "\n");
+
+    // make sure this much gets written to file in case future
+    // versions of OS break our crash dump code beyond this point.
+    fflush(stderr);
+
+    QCRPrintThreadState(crRef, stderr);
+    QCRPrintImages(crRef, stderr);
+}
