@@ -24,6 +24,8 @@ require_once('../inc/sandbox.inc');
 require_once('../inc/buda.inc');
 require_once('../inc/kw_prefs.inc');
 
+define('AVG_CPU_FPOPS', 4.3e9);
+
 display_errors();
 
 function submit_form($user) {
@@ -298,7 +300,8 @@ function handle_submit($user) {
     $max_runtime_days = (double)$max_runtime_days;
     if ($max_runtime_days <= 0) error_page('bad runtime limit');
     if ($max_runtime_days > 100) error_page('bad runtime limit');
-    $max_fpops = $max_runtime_days * 4.3e9 * 86400;
+
+    $max_fpops = $max_runtime_days * AVG_CPU_FPOPS * 86400;
 
     $exp_runtime_days = get_str('exp_runtime_days');
     if (!is_numeric($exp_runtime_days)) error_page('bad expected runtime');
@@ -308,7 +311,7 @@ function handle_submit($user) {
     if ($exp_runtime_days > $max_runtime_days) {
         error_page('exp must be < max runtime');
     }
-    $exp_fpops = $exp_runtime_days * 4.3e9 * 86400;
+    $exp_fpops = $exp_runtime_days * AVG_CPU_FPOPS * 86400;
 
     $app_desc = get_buda_app_desc($app);
 
