@@ -72,13 +72,15 @@ using std::string;
 int id_modulus=0, id_remainder=0;
 DB_ID_TYPE appid=0;
 bool dont_retry_errors = false;
-bool dont_delete_batches = false;
 bool do_input_files = true;
 bool do_output_files = true;
-bool dry_run = false;
+bool no_db_update = false;
 int sleep_interval = DEFAULT_SLEEP_INTERVAL;
 char *xml_doc_like = NULL;
 char *download_dir = NULL;
+bool preserve_wu_files = false;
+bool preserve_result_files = false;
+
 
 void usage(char *name) {
     fprintf(stderr, "Deletes files that are no longer needed.\n\n"
@@ -89,27 +91,25 @@ void usage(char *name) {
         "3) repeat from 1)\n"
         "4) every 1 hour, enumerate everything in state FILE_DELETE_ERROR\n"
         "   and try to delete it.\n"
-        "Usage: %s [OPTION]...\n\n"
+        "Usage: %s [OPTIONS]\n\n"
         "Options:\n"
-        "  -d N | --debug_level N          set debug output level (1 to 4)\n"
-        "  --mod M R                       handle only WUs with ID mod M == R\n"
-        "  --appid ID                      handle only WUs of app with id ID\n"
-        "  --app NAME                      handle only WUs of app with name NAME\n"
-        "  --one_pass                      instead of sleeping in 2), exit\n"
-        "  --dont_retry_error              don't do 4)\n"
-        "  --preserve_result_files         update the DB, but don't delete output files.\n"
-        "                                  For debugging.\n"
-        "  --preserve_wu_files             update the DB, but don't delete input files.\n"
-        "                                  For debugging.\n"
-        "  --dont_delete_batches           don't delete anything with positive batch number\n"
-        "  --input_files_only              delete only input (download) files\n"
-        "  --dry_run                       Don't update DB\n"
-        "                                  For debugging.\n"
-        "  --output_files_only             delete only output (upload) files\n"
-        "  --xml_doc_like L                only process workunits where xml_doc LIKE 'L'\n"
-        "  --download_dir D                override download_dir from project config with D\n"
-        "  [ -h | --help ]                 shows this help text\n"
-        "  [ -v | --version ]              shows version information\n",
+        "  -d N | --debug_level N       set debug output level (1 to 4)\n"
+        "  --mod M R                    handle only WUs with ID mod M == R\n"
+        "  --appid ID                   handle only WUs of app with id ID\n"
+        "  --app NAME                   handle only WUs of app with name NAME\n"
+        "  --one_pass                   instead of sleeping in 2), exit\n"
+        "  --dont_retry_error           don't do step 4) above\n"
+        "  --preserve_result_files      update the DB, but don't delete output files.\n"
+        "                               For debugging.\n"
+        "  --preserve_wu_files          update the DB, but don't delete input files.\n"
+        "                               For debugging.\n"
+        "  --input_files_only           delete only input (download) files\n"
+        "  --no_db_update               don't update wu/result file_delete_state\n"
+        "  --output_files_only          delete only output (upload) files\n"
+        "  --xml_doc_like L             only process workunits where xml_doc LIKE 'L'\n"
+        "  --download_dir D             override download_dir from project config with D\n"
+        "  [ -h | --help ]              shows this help text\n"
+        "  [ -v | --version ]           shows version information\n",
         name
     );
 }
@@ -274,9 +274,9 @@ int result_delete_files(RESULT& result) {
                     );
                 } else if (retval) {
                     // the fact that no result files were found is a critical
-                    // error if this was a successful result, but is to be
-                    // expected if the result outcome was failure, since in
-                    // that case there may well be no output file produced.
+                    // error if this was a successful result,
+                    // but is to be expected if the result outcome was failure,
+                    // since in that case no output file may have been produced.
                     //
                     int msg_mode;
                     if (RESULT_OUTCOME_SUCCESS == result.outcome) {
@@ -314,11 +314,6 @@ int result_delete_files(RESULT& result) {
     return mthd_retval;
 }
 
-// set by corresponding command line arguments.
-//
-static bool preserve_wu_files=false;
-static bool preserve_result_files=false;
-
 // return true if we changed the file_delete_state of a WU or a result
 //
 bool do_pass(bool retry_error) {
@@ -335,9 +330,6 @@ bool do_pass(bool retry_error) {
     if (id_modulus) {
         sprintf(clause, " and id %% %d = %d ", id_modulus, id_remainder);
     }
-    if (dont_delete_batches) {
-        strcat(clause, " and batch <= 0 ");
-    }
     if (appid) {
         sprintf(buf, " and appid = %lu ", appid);
         strcat(clause, buf);
@@ -374,7 +366,7 @@ bool do_pass(bool retry_error) {
         }
         if (new_state != result.file_delete_state) {
             sprintf(buf, "file_delete_state=%d", new_state);
-            if (dry_run) {
+            if (no_db_update) {
                 retval = 0;
             } else {
                 retval = result.update_field(buf);
@@ -428,7 +420,7 @@ bool do_pass(bool retry_error) {
         }
         if (new_state != wu.file_delete_state) {
             sprintf(buf, "file_delete_state=%d", new_state);
-            if (dry_run) {
+            if (no_db_update) {
                 retval = 0;
             } else {
                 retval = wu.update_field(buf);
@@ -526,20 +518,8 @@ int main(int argc, char** argv) {
             xml_doc_like = argv[i];
         } else if (is_arg(argv[i], "dont_delete_antiques")) {
             log_messages.printf(MSG_CRITICAL, "'%s' has no effect, this file deleter does no antique files deletion\n", argv[i]);
-        } else if (is_arg(argv[i], "antiques_deletion_dry_run")) {
-            log_messages.printf(MSG_CRITICAL, "'%s' has no effect, this file deleter does no antique files deletion\n", argv[i]);
-        } else if (is_arg(argv[i], "delete_antiques_interval")) {
-            log_messages.printf(MSG_CRITICAL, "'%s' has no effect, this file deleter does no antique files deletion\n", argv[i]);
-        } else if (is_arg(argv[i], "delete_antiques_usleep")) {
-            log_messages.printf(MSG_CRITICAL, "'%s' has no effect, this file deleter does no antique files deletion\n", argv[i]);
-        } else if (is_arg(argv[i], "delete_antiques_limit")) {
-            log_messages.printf(MSG_CRITICAL, "'%s' has no effect, this file deleter does no antique files deletion\n", argv[i]);
-        } else if (is_arg(argv[i], "dont_delete_batches")) {
-            dont_delete_batches = true;
-        } else if (is_arg(argv[i], "dry_run")) {
-            dry_run = true;
-        } else if (is_arg(argv[i], "delete_antiques_now")) {
-            log_messages.printf(MSG_CRITICAL, "'%s' has no effect, this file deleter does no antique files deletion\n", argv[i]);
+        } else if (is_arg(argv[i], "no_db_update")) {
+            no_db_update = true;
         } else if (is_arg(argv[i], "input_files_only")) {
             do_output_files = false;
         } else if (is_arg(argv[i], "output_files_only")) {
