@@ -320,7 +320,7 @@ int handle_file_upload(FILE* in, R_RSA_PUBLIC_KEY& key) {
     // TODO: use XML parser
 
     while (boinc::fgets(buf, 256, in)) {
-        log_messages.printf(MSG_DETAIL, "got:%s\n", buf);
+        log_messages.printf(MSG_DEBUG, "got:%s\n", buf);
         if (match_tag(buf, "<file_info>")) continue;
         if (match_tag(buf, "</file_info>")) continue;
         if (match_tag(buf, "<signed_xml>")) continue;
@@ -568,7 +568,7 @@ int handle_request(FILE* in, R_RSA_PUBLIC_KEY& key) {
     log_messages.set_indent_level(1);
 #endif
     while (boinc::fgets(buf, 256, in)) {
-        log_messages.printf(MSG_DETAIL, "handle_request: %s", buf);
+        log_messages.printf(MSG_DEBUG, "handle_request: %s", buf);
         if (parse_int(buf, "<core_client_major_version>", major)) {
             continue;
         } else if (parse_int(buf, "<core_client_minor_version>", minor)) {
