@@ -23,6 +23,7 @@
 #include "boinc_db.h"
 #include "sched_shmem.h"
 #include "sched_types.h"
+#include "buda.h"
 
 const int MAX_GPUS = 64;
     // don't believe clients who claim they have more GPUs than this
@@ -33,17 +34,10 @@ extern void send_work();
 
 extern int add_result_to_reply(
     SCHED_DB_RESULT& result, WORKUNIT& wu, BEST_APP_VERSION* bavp,
-    HOST_USAGE&,
-    bool is_buda,
+    HOST_USAGE&, BUDA_VARIANT*,
     bool locality_scheduling
 );
 
-// if WU has plan class, check host, and get corresponding host_usage
-//
-extern void check_buda_plan_class(
-    WORKUNIT &wu, HOST_USAGE &host_usage, bool &is_buda, bool &is_ok
-);
-
 inline bool is_anonymous(PLATFORM* platform) {
     return (!strcmp(platform->name, "anonymous"));
 }
