@@ -36,6 +36,7 @@
 #include "sched_types.h"
 #include "sched_util.h"
 #include "credit.h"
+#include "buda.h"
 
 #include "sched_version.h"
 
@@ -761,12 +762,14 @@ BEST_APP_VERSION* get_app_version(
                 }
             }
 
+            // if app version has plan class, make sure host can handle it
+            //
             if (strlen(av.plan_class)) {
                 if (!app_plan(*g_request, av.plan_class, host_usage, &wu)) {
                     if (config.debug_version_select) {
                         log_messages.printf(MSG_NORMAL,
-                            "[version] [AV#%lu] app_plan() returned false\n",
-                            av.id
+                            "[version] [AV#%lu] app_plan(%s) returned false\n",
+                            av.id, av.plan_class
                         );
                     }
                     continue;
@@ -948,6 +951,13 @@ BEST_APP_VERSION* get_app_version(
         if (config.prefer_primary_platform && found_feasible_version) {
             break;
         }
+
+        // use only primary platform for BUDA jobs
+        // (e.g. don't send Intel docker_wrapper to Mac/ARM)
+        //
+        if (is_buda(wu)) {
+            break;
+        }
     }   // loop over client platforms
 
     if (bavp->avp) {
@@ -980,4 +990,3 @@ BEST_APP_VERSION* get_app_version(
     }
     return bavp;
 }
-
