@@ -25,6 +25,16 @@
 // - to create a single job, with everything passed on the cmdline
 // - to create multiple jobs, where per-job info is passed via stdin,
 //      one line per job
+//      available options here:
+//      --command_line X
+//      --wu_name X
+//      --wu_template F
+//      --result_template F
+//      --remote_file url nbytes md5
+//      --target_host ID
+//      --target_user ID
+//      --priority N
+//      phys_name1 ...
 //
 // The input files must already be staged (i.e. in the download hierarchy).
 
@@ -50,6 +60,11 @@
 
 #include "backend_lib.h"
 
+// the max length of a job description line;
+// also the max length of a job command line
+//
+#define CMD_SIZE    4096
+
 using std::string;
 using std::map;
 
@@ -86,6 +101,7 @@ void usage() {
         "   [ --rsc_memory_bound x ]\n"
         "   [ --size_class n ]\n"
         "   [ --stdin ]\n"
+        "   [ --sub_appname 'foo bar' ]\n"
         "   [ --target_host ID ]\n"
         "   [ --target_nresults n ]\n"
         "   [ --target_team ID ]\n"
@@ -128,21 +144,23 @@ struct JOB_DESC {
     char result_template_file[256];
     char result_template_path[MAXPATHLEN];
     vector <INFILE_DESC> infiles;
-    char* command_line;
+    char command_line[CMD_SIZE];
     bool assign_flag;
     bool assign_multi;
     int assign_id;
     int assign_type;
+    char sub_appname[256];
 
     JOB_DESC() {
         wu.clear();
-        command_line = NULL;
+        command_line[0] = 0;
         assign_flag = false;
         assign_multi = false;
-        strcpy(wu_template_file, "");
-        strcpy(result_template_file, "");
+        wu_template_file[0] = 0;
+        result_template_file[0] = 0;
         assign_id = 0;
         assign_type = ASSIGN_NONE;
+        sub_appname[0] = 0;
 
         // defaults (in case they're not in WU template)
         //
@@ -162,15 +180,19 @@ struct JOB_DESC {
 
     }
     void create();
-    void parse_cmdline(int, char**);
+    void parse_stdin_line(int, char**);
 };
 
 // parse additional job-specific info when using --stdin
 //
-void JOB_DESC::parse_cmdline(int argc, char** argv) {
+void JOB_DESC::parse_stdin_line(int argc, char** argv) {
     for (int i=0; i<argc; i++) {
         if (arg(argv, i, (char*)"command_line")) {
-            command_line = argv[++i];
+            // concatenate per-job args to main args
+            if (strlen(command_line)) {
+                strcat(command_line, " ");
+            }
+            strcat(command_line, argv[++i]);
         } else if (arg(argv, i, (char*)"wu_name")) {
             safe_strcpy(wu.name, argv[++i]);
         } else if (arg(argv, i, (char*)"wu_template")) {
@@ -234,13 +256,22 @@ void get_wu_template(JOB_DESC& jd2) {
     strcpy(jd2.wu_template, wu_templates[s]);
 }
 
+// if a buffer is full after a fgets(), it was too small
+//
+void check_buffer(char *p, int len) {
+    if (strlen(p) == len-1) {
+        fprintf(stderr, "fgets() buffer was too small\n");
+        exit(1);
+    }
+}
+
 int main(int argc, char** argv) {
     DB_APP app;
     int retval;
     int i;
     char download_dir[256], db_name[256], db_passwd[256];
     char db_user[256],db_host[256];
-    char buf[4096];
+    char buf[CMD_SIZE];
     JOB_DESC jd;
     bool show_wu_name = true;
     bool use_stdin = false;
@@ -298,10 +329,8 @@ int main(int argc, char** argv) {
             jd.wu.max_total_results = atoi(argv[++i]);
         } else if (arg(argv, i, "max_success_results")) {
             jd.wu.max_success_results = atoi(argv[++i]);
-        } else if (arg(argv, i, "opaque")) {
-            jd.wu.opaque = atoi(argv[++i]);
         } else if (arg(argv, i, "command_line")) {
-            jd.command_line= argv[++i];
+            strcpy(jd.command_line, argv[++i]);
         } else if (arg(argv, i, "wu_id")) {
             jd.wu.id = atoi(argv[++i]);
         } else if (arg(argv, i, "broadcast")) {
@@ -353,6 +382,8 @@ int main(int argc, char** argv) {
             continue_on_error = true;
         } else if (arg(argv, i, "keywords")) {
             strcpy(jd.wu.keywords, argv[++i]);
+        } else if (arg(argv, i, "sub_appname")) {
+            strcpy(jd.sub_appname, argv[++i]);
         } else {
             if (!strncmp("-", argv[i], 1)) {
                 fprintf(stderr, "create_work: bad argument '%s'\n", argv[i]);
@@ -436,10 +467,6 @@ int main(int argc, char** argv) {
     strcat(jd.result_template_path, jd.result_template_file);
 
     if (use_stdin) {
-        // clear the WU template name so we'll recognize a job-level one
-        //
-        strcpy(jd.wu_template_file, "");
-
         if (jd.assign_flag) {
             // if we're doing assignment we can't use the bulk-query method;
             // create the jobs one at a time.
@@ -449,11 +476,12 @@ int main(int argc, char** argv) {
             for (int j=0; ; j++) {
                 char* p = fgets(buf, sizeof(buf), stdin);
                 if (p == NULL) break;
+                check_buffer(buf, sizeof(buf));
                 JOB_DESC jd2 = jd;
                     // things default to what was passed on cmdline
                 strcpy(jd2.wu.name, "");
                 _argc = parse_command_line(buf, _argv);
-                jd2.parse_cmdline(_argc, _argv);
+                jd2.parse_stdin_line(_argc, _argv);
                     // get info from stdin line
                 if (!strlen(jd2.wu.name)) {
                     snprintf(jd2.wu.name, sizeof(jd2.wu.name), "%s_%d", jd.wu.name, j);
@@ -468,17 +496,31 @@ int main(int argc, char** argv) {
                 jd2.create();
             }
         } else {
+            // stdin mode, unassigned.
+            // for max efficiency, do them all in one big SQL query
+            //
             string values;
             DB_WORKUNIT wu;
             int _argc;
             char* _argv[100], value_buf[MAX_QUERY_LEN];
+
+            char additional_xml[256];
+            additional_xml[0] = 0;
+            if (strlen(jd.sub_appname)) {
+                snprintf(additional_xml, sizeof(additional_xml),
+                    "   <sub_appname>%s</sub_appname>",
+                    jd.sub_appname
+                );
+            }
+
             for (int j=0; ; j++) {
                 char* p = fgets(buf, sizeof(buf), stdin);
                 if (p == NULL) break;
+                check_buffer(buf, sizeof(buf));
                 JOB_DESC jd2 = jd;
                 strcpy(jd2.wu.name, "");
                 _argc = parse_command_line(buf, _argv);
-                jd2.parse_cmdline(_argc, _argv);
+                jd2.parse_stdin_line(_argc, _argv);
                 if (!strlen(jd2.wu.name)) {
                     snprintf(jd2.wu.name, sizeof(jd2.wu.name), "%s_%d", jd.wu.name, j);
                 }
@@ -507,7 +549,7 @@ int main(int argc, char** argv) {
                     jd2.infiles,
                     config,
                     jd2.command_line,
-                    NULL,
+                    additional_xml,
                     value_buf
                 );
                 if (retval) {
@@ -564,10 +606,20 @@ int main(int argc, char** argv) {
     boinc_db.close();
 }
 
+// create a single job
+//
 void JOB_DESC::create() {
     if (assign_flag) {
         wu.transitioner_flags = assign_multi?TRANSITION_NONE:TRANSITION_NO_NEW_RESULTS;
     }
+    char additional_xml[256], kwbuf[256];
+    additional_xml[0] = 0;
+    if (strlen(sub_appname)) {
+        snprintf(additional_xml, sizeof(additional_xml),
+            "   <sub_appname>%s</sub_appname>",
+            sub_appname
+        );
+    }
     int retval = create_work2(
         wu,
         wu_template,
@@ -575,7 +627,8 @@ void JOB_DESC::create() {
         result_template_path,
         infiles,
         config,
-        command_line
+        command_line,
+        additional_xml
     );
     if (retval) {
         fprintf(stderr, "create_work: %s\n", boincerror(retval));
