@@ -397,7 +397,10 @@ static int process_file_info(
     return 0;
 }
 
-// parse the <workunit> elements, which includes file refs and job params
+// Process the <workunit> section of an input template.
+// Copy resource usage and replication params to 'wu'.
+// Append XML (the workunit's xml_doc) to 'out'.
+// Add the given command line and additional XML.
 //
 static int process_workunit(
     XML_PARSER& xp, WORKUNIT& wu, string& out,
@@ -468,8 +471,11 @@ static int process_workunit(
             }
             n_file_refs++;
         } else if (xp.parse_string("command_line", cmdline)) {
-            if (command_line) {
-                boinc::fprintf(stderr, "Can't specify command line twice\n");
+            if (strlen(command_line)) {
+                boinc::fprintf(stderr,
+                    "Can't specify command line %s; already specified as %s\n",
+                    cmdline.c_str(), command_line
+                );
                 return ERR_XML_PARSE;
             }
             out += "<command_line>\n";
@@ -508,6 +514,16 @@ static int process_workunit(
             out += "\n";
         }
     }
+
+    // fill in possibly missing parameters
+    //
+    if (wu.target_nresults > wu.max_success_results) {
+        wu.max_success_results = wu.target_nresults;
+    }
+    if (wu.target_nresults > wu.max_total_results) {
+        wu.max_total_results = wu.target_nresults;
+    }
+
     if (n_file_refs != (int)infiles.size()) {
         boinc::fprintf(stderr, "#file refs != #file infos\n");
         return ERR_XML_PARSE;
